@@ -2,7 +2,7 @@
 %%
 %% %CopyrightBegin%
 %%
-%% Copyright Ericsson AB 2009-2011. All Rights Reserved.
+%% Copyright Ericsson AB 2009-2016. All Rights Reserved.
 %%
 %% Licensed under the Apache License, Version 2.0 (the "License");
 %% you may not use this file except in compliance with the License.
@@ -54,24 +54,24 @@ top_index() ->
 	    top_index(src, Value, filename:join(Value, "doc"), RelName)
     end.
 
-top_index([src, RootDir, DestDir, OtpRel])
-  when is_atom(RootDir), is_atom(DestDir), is_atom(OtpRel) ->
-    top_index(src, atom_to_list(RootDir), atom_to_list(DestDir), atom_to_list(OtpRel));
-top_index([rel, RootDir, DestDir, OtpRel])
-  when is_atom(RootDir), is_atom(DestDir), is_atom(OtpRel) ->
-    top_index(rel, atom_to_list(RootDir), atom_to_list(DestDir), atom_to_list(OtpRel));
+top_index([src, RootDir, DestDir, OtpBaseVsn])
+  when is_atom(RootDir), is_atom(DestDir), is_atom(OtpBaseVsn) ->
+    top_index(src, atom_to_list(RootDir), atom_to_list(DestDir), atom_to_list(OtpBaseVsn));
+top_index([rel, RootDir, DestDir, OtpBaseVsn])
+  when is_atom(RootDir), is_atom(DestDir), is_atom(OtpBaseVsn) ->
+    top_index(rel, atom_to_list(RootDir), atom_to_list(DestDir), atom_to_list(OtpBaseVsn));
 top_index(RootDir)  when is_atom(RootDir) -> 
     {_,RelName} = init:script_id(),
     top_index(rel, RootDir, filename:join(RootDir, "doc"), RelName).
 
 
 
-top_index(Source, RootDir, DestDir, OtpRel) ->
+top_index(Source, RootDir, DestDir, OtpBaseVsn) ->
     report("****\nRootDir: ~p", [RootDir]),
     report("****\nDestDir: ~p", [DestDir]),
-    report("****\nOtpRel: ~p", [OtpRel]),
+    report("****\nOtpBaseVsn: ~p", [OtpBaseVsn]),
 
-    put(otp_release, OtpRel),
+    put(otp_base_vsn, OtpBaseVsn),
 
     Templates = find_templates(["","templates",DestDir]),
     report("****\nTemplates: ~p", [Templates]),
@@ -81,9 +81,9 @@ top_index(Source, RootDir, DestDir, OtpRel) ->
     report("****\nGroups: ~p", [Groups]),
     process_templates(Templates, DestDir, Groups).
 
-top_index_silent(RootDir, DestDir, OtpRel) ->
+top_index_silent(RootDir, DestDir, OtpBaseVsn) ->
     put(silent,true),
-    Result = top_index(rel, RootDir, DestDir, OtpRel),
+    Result = top_index(rel, RootDir, DestDir, OtpBaseVsn),
     erase(silent),
     Result.
 
@@ -361,7 +361,7 @@ subst_template_1(Group, Stream, Info) ->
     case file:read(Stream, 100000) of
 	{ok, Template} ->
 	    Fun = fun(Match, _) -> {subst(Match, Info, Group),Info} end,
-	    gsub(Template, "#[A-Za-z0-9]+#", Fun, Info);
+	    gsub(Template, "#[A-Za-z_0-9]+#", Fun, Info);
 	{error, Reason} ->
 	    {error, Reason}
     end.
@@ -379,8 +379,8 @@ get_version(Info) ->
 	    ""
     end.
 		    
-subst("#release#", _Info, _Group) ->
-    get(otp_release);
+subst("#otp_base_vsn#", _Info, _Group) ->
+    get(otp_base_vsn);
 subst("#version#", Info, _Group) ->
     get_version(Info);
 subst("#copyright#", _Info, _Group) ->
